=========
XDGTrash
=========
:Name: XDGTrash
:Module: xdgtrash
:Author: Kwpolska
:Specification: XDG/freedesktop <http://freedesktop.org/wiki/Specifications/trash-spec>
:OS: Linux (KDE, GNOME, Xfce and others conforming to this spec)
:Description: An XDG trash implementation.
:Copyright: See Appendix A.
:Date: 2012-08-25
:Version: 0.2.4

.. index:: XDGTrash

.. automodule:: trashman.backends.xdgtrash
   :members:
